==================
CDS-DoJSON v0.9.0
==================

DoJSON v0.9.0 was released on June 4, 2018.

About
-----

CDS DoJSON is an extension of DoJSON package with the customization for CDS.

New features and fixes
----------------------

- Remove the DOI from the required fields.

Installation
------------

   $ pip install cds-dojson==0.9.0

Documentation
-------------

    https://cds-dojson.readthedocs.org/en/v0.9.0

    Happy hacking and thanks for flying DoJSON.

    | CERN Document Serveer Team
    |   Email: cds.support@cern.ch
    |   GitHub: https://github.com/CERNDocumentServer/cds-dojson
    |   URL: https://cds.cern.ch
